@@ -7,26 +7,24 @@ import requests
 
 from openprotein.base import APISession
 from openprotein.api.jobs import (
-    Job,
     AsyncJobFuture,
     StreamingAsyncJobFuture,
-    job_get,
-    job_args_get,
 )
+
+from openprotein.jobs import MultiJob, JobType,JobStatus, job_get, job_args_get
+
 from openprotein.api.jobs import load_job #as base_load_job
 import openprotein.config as config
 
 from openprotein.models import (
     MSASamplingMethod,
     PoetInputType,
-    PoetScoreJob,
     PoetScoreResult,
-    PromptJob,
-    MSAJob,
-    JobType,
-    PoetSSPJob,
     PoetSSPResult,
 )
+
+from openprotein.jobs import MultiJob, JobType
+
 from openprotein.errors import (
     InvalidParameterError,
     MissingParameterError,
@@ -35,9 +33,6 @@ from openprotein.errors import (
 )
 
 
-#def load_job(session, job_id):
-#    return base_load_job(session, job_id)
-
 
 def csv_stream(response: requests.Response) -> csv.reader:
     """
@@ -101,7 +96,7 @@ def get_align_job_inputs(
 
 def get_input(
     self: APISession,
-    job: Job,
+    job: MultiJob,
     input_type: PoetInputType,
     prompt_index: Optional[int] = None,
 ) -> csv.reader:
@@ -130,7 +125,7 @@ def get_input(
 
 
 def get_prompt(
-    self: APISession, job: Job, prompt_index: Optional[int] = None
+    self: APISession, job: MultiJob, prompt_index: Optional[int] = None
 ) -> csv.reader:
     """
     Get the prompt for a given job.
@@ -152,7 +147,7 @@ def get_prompt(
     return get_input(self, job, PoetInputType.PROMPT, prompt_index=prompt_index)
 
 
-def get_seed(self: APISession, job: Job) -> csv.reader:
+def get_seed(self: APISession, job: MultiJob) -> csv.reader:
     """
     Get the seed for a given MSA job.
 
@@ -171,7 +166,7 @@ def get_seed(self: APISession, job: Job) -> csv.reader:
     return get_input(self, job, PoetInputType.INPUT)
 
 
-def get_msa(self: APISession, job: Job) -> csv.reader:
+def get_msa(self: APISession, job: MultiJob) -> csv.reader:
     """
     Get the generated MSA (Multiple Sequence Alignment) for a given job.
 
@@ -232,7 +227,7 @@ def msa_post(session: APISession, msa_file=None, seed=None):
     files = {"msa_file": msa_file}
 
     response = session.post(endpoint, files=files, params=params)
-    return MSAJob(**response.json())
+    return MultiJob.parse_obj(response.json() )
 
 
 def prompt_post(
@@ -333,13 +328,13 @@ def prompt_post(
         params["max_msa_tokens"] = num_residues
 
     response = session.post(endpoint, params=params)
-    return PromptJob(**response.json())
+    return MultiJob.parse_obj(response.json() )
 
 
 def upload_prompt_post(
     session: APISession,
     prompt_file: BinaryIO,
-) -> PromptJob:
+) -> MultiJob:
     """
     Directly upload a prompt.
 
@@ -365,17 +360,17 @@ def upload_prompt_post(
     """
 
     endpoint = "v1/poet/align/upload_prompt"
-    files = {"prompt_file ": prompt_file}
+    files = {"prompt_file": prompt_file}
     try:
         response = session.post(endpoint, files=files)
-        return PromptJob(**response.json())
+        return MultiJob.parse_obj(response.json() )
     except Exception as exc:
         raise APIError(f"Failed to upload prompt post: {exc}") from exc
 
 
 def poet_score_post(
-    session: APISession, prompt_id: str, queries: List[str]
-) -> PoetScoreJob:
+    session: APISession, prompt_id: str, queries: List[bytes]
+) -> MultiJob:
     """
     Submits a job to score sequences based on the given prompt.
 
@@ -405,13 +400,15 @@ def poet_score_post(
     if not prompt_id:
         raise MissingParameterError("Must include prompt_id in request!")
 
+    if isinstance(queries[0], str):
+        queries = [i.encode() for i in queries]
     try:
         variant_file = BytesIO(b"\n".join(queries))
         params = {"prompt_id": prompt_id}
         response = session.post(
             endpoint, files={"variant_file": variant_file}, params=params
         )
-        return PoetScoreJob(**response.json())
+        return MultiJob.parse_obj(response.json() )
     except Exception as exc:
         raise APIError(f"Failed to post poet score: {exc}") from exc
 
@@ -455,12 +452,12 @@ def poet_score_get(
         params={"job_id": job_id, "page_size": page_size, "page_offset": page_offset},
     )
 
-    return PoetScoreJob(**response.json())
+    return MultiJob.parse_obj(response.json() )
 
 
 class PoetFutureMixin:
     session: APISession
-    job: Job
+    job: MultiJob
 
     def get_input(self, input_type: PoetInputType):
         """See child function docs."""
@@ -507,7 +504,7 @@ class MSAFuture(PoetFutureMixin, AsyncJobFuture):
         The list of results from the PoET scoring job.
     """
 
-    def __init__(self, session: APISession, job: Job, page_size=config.POET_PAGE_SIZE):
+    def __init__(self, session: APISession, job: MultiJob, page_size=config.POET_PAGE_SIZE):
         """
         init a PoetScoreFuture instance.
 
@@ -648,7 +645,7 @@ class PromptFuture(MSAFuture):
     def __init__(
         self,
         session: APISession,
-        job: Job,
+        job: MultiJob,
         page_size=config.POET_PAGE_SIZE,
         msa_id: Optional[str] = None,
     ):
@@ -690,7 +687,7 @@ class PoetScoreFuture(PoetFutureMixin, AsyncJobFuture):
 
     """
 
-    def __init__(self, session: APISession, job: Job, page_size=config.POET_PAGE_SIZE):
+    def __init__(self, session: APISession, job: MultiJob, page_size=config.POET_PAGE_SIZE):
         """
         init a PoetScoreFuture instance.
 
@@ -750,7 +747,7 @@ class PoetScoreFuture(PoetFutureMixin, AsyncJobFuture):
 
 def poet_single_site_post(
     session: APISession, variant, parent_id=None, prompt_id=None
-) -> PoetSSPJob:
+) -> MultiJob:
     """
     Request PoET single-site analysis for a variant.
 
@@ -794,14 +791,14 @@ def poet_single_site_post(
 
     try:
         response = session.post(endpoint, params=params)
-        return PoetSSPJob(**response.json())
+        return MultiJob.parse_obj(response.json()) 
     except Exception as exc:
         raise APIError(f"Failed to post poet single-site analysis: {exc}") from exc
 
 
 def poet_single_site_get(
     session: APISession, job_id: str, page_size: int = 100, page_offset: int = 0
-) -> PoetSSPJob:
+) -> MultiJob:
     """
     Fetch paged results of a PoET single-site analysis job.
 
@@ -832,7 +829,7 @@ def poet_single_site_get(
 
     try:
         response = session.get(endpoint, params=params)
-        return PoetSSPJob(**response.json())
+        return MultiJob.parse_obj(response.json()) 
     except Exception as exc:
         raise APIError(
             f"Failed to get poet single-site analysis results: {exc}"
@@ -859,7 +856,7 @@ class PoetSingleSiteFuture(PoetFutureMixin, AsyncJobFuture):
 
     """
 
-    def __init__(self, session: APISession, job: Job, page_size=config.POET_PAGE_SIZE):
+    def __init__(self, session: APISession, job: MultiJob, page_size=config.POET_PAGE_SIZE):
         """
         init a PoetSingleSiteFuture instance.
 
@@ -926,7 +923,7 @@ def poet_generate_post(
     topp=None,
     max_length=1000,
     random_seed=None,
-) -> Job:
+) -> MultiJob:
     """
     Generate protein sequences with a prompt.
 
@@ -990,7 +987,7 @@ def poet_generate_post(
 
     try:
         response = session.post(endpoint, params=params)
-        return Job(**response.json())
+        return MultiJob.parse_obj(response.json())
     except Exception as exc:
         raise APIError(f"Failed to post PoET generation request: {exc}") from exc
 
@@ -1086,6 +1083,12 @@ def validate_prompt(prompt: Prompt):
         prompt_id = prompt.prompt_id
     return prompt_id
 
+def validate_msa(msa: Union[MSAFuture, str]):
+    """helper function to validate prompt_id is prompt type"""
+    msa_id = msa
+    if isinstance(msa, MSAFuture) or isinstance(msa, MultiJob):
+        msa_id = msa.msa_id
+    return msa_id
 
 class PoetAPI:
     """API interface for calling Poet and Align endpoints"""
@@ -1093,7 +1096,7 @@ class PoetAPI:
     def __init__(self, session: APISession):
         self.session = session
 
-    def load_prompt_job(self, prompt_id: str) -> PromptFuture:
+    def load_job(self, job_id: str) -> PromptFuture:
         """
         Reload a previously ran prompt job to resume where you left off.
 
@@ -1112,68 +1115,21 @@ class PoetAPI:
         PromptFuture
             Job to resume workflows.
         """
-        job = load_job(self.session, prompt_id)
-        if job.job_type != JobType.align_prompt:
-            raise InvalidJob(f"job {prompt_id} is not a prompt job!")
-        msa_id = job_args_get(self.session, prompt_id).get("root_msa")
-        return PromptFuture(self.session, job, msa_id=msa_id)
-
-    def load_msa_job(self, msa_id: str) -> MSAFuture:
-        """
-        Reload a previously ran MSA job to resume where you left off.
-
-        Parameters
-        ----------
-        msa_id : str
-            ID for job.
-
-        Raises
-        ------
-        InvalidJob
-            If job is of incorrect type.
-
-        Returns
-        -------
-        PromptFuture
-            Job to resume workflows.
-        """
-        job = load_job(self.session, msa_id)
-        if job.job_type != JobType.align:
-            raise InvalidJob(f"job {msa_id} is not a MSA job!")
-        return MSAFuture(self.session, job)
-
-    def load_poet_job(self,
-                      job_id: str
-                      ) -> Union[PoetSingleSiteFuture,
-                                 PoetScoreFuture,
-                                 PoetGenerateFuture]:
-        """
-        Reload a previously ran Poet job to resume where you left off.
-
-        Parameters
-        ----------
-        job_id : str
-            ID for job.
-
-        Raises
-        ------
-        InvalidJob
-            If job is of incorrect type.
-
-        Returns
-        -------
-        PoetFuture
-            Job to resume workflows.
-        """
         job = load_job(self.session, job_id)
-        if job.job_type == JobType.prots2prot_single_site:
+        if job.job_type == JobType.align:
+            return MSAFuture(self.session, job) 
+        elif job.job_type == JobType.align_prompt:
+            msa_id = job_args_get(self.session, job_id).get("root_msa")
+            job.msa_id = msa_id
+            return PromptFuture(self.session, job, msa_id=msa_id)
+        elif job.job_type == JobType.prots2prot_single_site:
             return PoetSingleSiteFuture(self.session, job)
-        if job.job_type == JobType.prots2prot:
+        elif job.job_type == JobType.prots2prot:
             return PoetScoreFuture(self.session, job)
-        if job.job_type == JobType.prots2prot_generate:
+        elif job.job_type == JobType.prots2prot_generate:
             return PoetGenerateFuture(self.session, job)
-        else:
-            raise InvalidJob(f"job {job_id} is not a PoET job!")
+        
+
 
     def upload_msa(self, msa_file) -> MSAFuture:
         """
@@ -1219,7 +1175,7 @@ class PoetAPI:
         job = msa_post(self.session, seed=seed)
         return MSAFuture(self.session, job)
 
-    def upload_prompt(self, prompt_file: BinaryIO) -> PromptJob:
+    def upload_prompt(self, prompt_file: BinaryIO) -> MultiJob:
         """
         Directly upload a prompt.
 
@@ -1244,7 +1200,7 @@ class PoetAPI:
         job = upload_prompt_post(self.session, prompt_file)
         return PromptFuture(self.session, job)
 
-    def get_prompt(self, job: Job, prompt_index: Optional[int] = None) -> csv.reader:
+    def get_prompt(self, job: MultiJob, prompt_index: Optional[int] = None) -> csv.reader:
         """
         Get prompts for a given job.
 
@@ -1264,7 +1220,7 @@ class PoetAPI:
             self.session, job, PoetInputType.PROMPT, prompt_index=prompt_index
         )
 
-    def get_seed(self, job: Job) -> csv.reader:
+    def get_seed(self, job: MultiJob) -> csv.reader:
         """
         Get input data for a given msa job.
 
@@ -1280,7 +1236,7 @@ class PoetAPI:
         """
         return get_input(self.session, job, PoetInputType.INPUT)
 
-    def get_msa(self, job: Job) -> csv.reader:
+    def get_msa(self, job: MultiJob) -> csv.reader:
         """
         Get generated MSA for a given job.
 
@@ -1296,41 +1252,6 @@ class PoetAPI:
         """
         return get_input(self.session, job, PoetInputType.MSA)
 
-    def get_prompt_job(self, job_id: str) -> PromptJob:
-        """
-        Get prompt job based on job_id.
-
-        Parameters
-        ----------
-        job_id: str
-            job ID for a prompt job
-
-        Returns
-        ----------
-        PromptJob
-            A prompt job instance
-        """
-        job = job_get(self.session, job_id)
-        assert job.job_type == "/align/prompt"
-        return PromptJob(**job.dict(), prompt_id=job.job_id)
-
-    def get_msa_job(self, job_id: str) -> MSAJob:
-        """
-        Get MSA job based on job_id.
-
-        Parameters
-        ----------
-        job_id: str
-            job ID for a prompt job
-
-        Returns
-        ----------
-        MSAJob
-            A prompt job instance
-        """
-        job = job_get(self.session, job_id)
-        assert job.job_type == "/align/align"
-        return MSAJob(**job.dict(), msa_id=job.job_id)
 
     def score(self, prompt: Prompt, queries: List[bytes]) -> PoetScoreFuture:
         """
